==> jc-1.4.0.tar.gz: java/util/jar/JarException.h <==
// public class java.util.jar.JarException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ba11d633c7213e05 java_util_jar_JarException
// @dep_class cd59cf72c34ef3f3 java_util_zip_ZipException

// header file dependencies
// @dep_header java_util_zip_ZipException

#include "java/util/zip/ZipException.h"

#ifndef _JC_java_util_jar_JarException_H_
#define _JC_java_util_jar_JarException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_jar_JarException$sub_refs	_jc_java_util_jar_JarException$sub_refs;
typedef struct _jc_java_util_jar_JarException$sub_nonrefs	_jc_java_util_jar_JarException$sub_nonrefs;
typedef struct _jc_java_util_jar_JarException$refs	_jc_java_util_jar_JarException$refs;
typedef struct _jc_java_util_jar_JarException$nonrefs	_jc_java_util_jar_JarException$nonrefs;
typedef struct _jc_java_util_jar_JarException$object	_jc_java_util_jar_JarException$object;

typedef struct _jc_java_util_jar_JarException$fields_struct	_jc_java_util_jar_JarException$fields_struct;
typedef const struct _jc_java_util_jar_JarException$vmethods	_jc_java_util_jar_JarException$vmethods;
typedef const struct _jc_java_util_jar_JarException$vtable	_jc_java_util_jar_JarException$vtable;
typedef const struct _jc_java_util_jar_JarException$vtype	_jc_java_util_jar_JarException$vtype;

// Class fields structure
struct _jc_java_util_jar_JarException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_jar_JarException$fields_struct _jc_java_util_jar_JarException$class_fields;

// Constructors
extern void _jc_java_util_jar_JarException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_jar_JarException$object *);
extern void _jc_java_util_jar_JarException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_jar_JarException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_util_jar_JarException$vmethods {
};

// Vtable
struct _jc_java_util_jar_JarException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_util_zip_ZipException$vmethods	java_util_zip_ZipException;
	_jc_java_util_jar_JarException$vmethods	java_util_jar_JarException;
};

// Vtype
struct _jc_java_util_jar_JarException$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarException$refs {
    _jc_java_util_jar_JarException$sub_refs	java_util_jar_JarException;
    _jc_java_util_zip_ZipException$sub_refs	java_util_zip_ZipException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_util_zip_ZipException$sub_nonrefs	java_util_zip_ZipException;
    _jc_java_util_jar_JarException$sub_nonrefs	java_util_jar_JarException;
};

// Object instance structure
struct _jc_java_util_jar_JarException$object {
	_jc_java_util_jar_JarException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarException$vtype	*vtype;
	_jc_java_util_jar_JarException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarException$vtype _jc_java_util_jar_JarException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarException$class_object;

#endif	/* _JC_java_util_jar_JarException_H_ */

==> jc-1.4.6.tar.gz: java/util/jar/JarException.h <==
// public class java.util.jar.JarException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ba11d633c7213e05 java_util_jar_JarException
// @dep_class cd59cf72c34ef3f3 java_util_zip_ZipException

// header file dependencies
// @dep_header java_util_zip_ZipException

#include "java/util/zip/ZipException.h"

#ifndef _JC_java_util_jar_JarException_H_
#define _JC_java_util_jar_JarException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_jar_JarException$sub_refs	_jc_java_util_jar_JarException$sub_refs;
typedef struct _jc_java_util_jar_JarException$sub_nonrefs	_jc_java_util_jar_JarException$sub_nonrefs;
typedef struct _jc_java_util_jar_JarException$refs	_jc_java_util_jar_JarException$refs;
typedef struct _jc_java_util_jar_JarException$nonrefs	_jc_java_util_jar_JarException$nonrefs;
typedef struct _jc_java_util_jar_JarException$object	_jc_java_util_jar_JarException$object;

typedef struct _jc_java_util_jar_JarException$fields_struct	_jc_java_util_jar_JarException$fields_struct;
typedef const struct _jc_java_util_jar_JarException$vmethods	_jc_java_util_jar_JarException$vmethods;
typedef const struct _jc_java_util_jar_JarException$vtable	_jc_java_util_jar_JarException$vtable;
typedef const struct _jc_java_util_jar_JarException$vtype	_jc_java_util_jar_JarException$vtype;

// Class fields structure
struct _jc_java_util_jar_JarException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_jar_JarException$fields_struct _jc_java_util_jar_JarException$class_fields;

// Constructors
extern void _jc_java_util_jar_JarException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_jar_JarException$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_jar_JarException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_jar_JarException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_jar_JarException$vmethods {
};

// Vtable
struct _jc_java_util_jar_JarException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_util_zip_ZipException$vmethods	java_util_zip_ZipException;
	_jc_java_util_jar_JarException$vmethods	java_util_jar_JarException;
};

// Vtype
struct _jc_java_util_jar_JarException$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarException$refs {
    _jc_java_util_jar_JarException$sub_refs	java_util_jar_JarException;
    _jc_java_util_zip_ZipException$sub_refs	java_util_zip_ZipException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_util_zip_ZipException$sub_nonrefs	java_util_zip_ZipException;
    _jc_java_util_jar_JarException$sub_nonrefs	java_util_jar_JarException;
};

// Object instance structure
struct _jc_java_util_jar_JarException$object {
	_jc_java_util_jar_JarException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarException$vtype	*vtype;
	_jc_java_util_jar_JarException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarException$vtype _jc_java_util_jar_JarException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarException$class_object;

#endif	/* _JC_java_util_jar_JarException_H_ */
